Crate opentalk_client_data_persistence

Crate opentalk_client_data_persistence 

Data persistency functions for the OpenTalk client library

Structs

AccountTokens
The token data required to authorize client requests to the OpenTalk API.
Config
Config to store needable state of the opentalk client
ConfigManager
The ConfigManager stores and loads configs from providered pathes
DataError
The error returned from functions in this crate.
OpenTalkAccountConfig
Configuration of an OpenTalk account.
OpenTalkAccountId
The id of an OpenTalk account.
OpenTalkInstanceAccountId
The full id of a stored OpenTalk account, including the OpenTalkInstanceId and the OpenTalkAccountId.
OpenTalkInstanceConfig
Configuration of an OpenTalk instance.
OpenTalkInstanceId
The id of an OpenTalk instance in the format of a URL.

Enums

ConfigError
The error returned from config functions in this crate.

Traits

DataManager
The DataManager defines the interface for storing and loading data for the OpenTalk client locally