Config

Struct Config 

pub struct Config {
    pub default_instance: Option<OpenTalkInstanceId>,
    pub instances: BTreeMap<OpenTalkInstanceId, OpenTalkInstanceConfig>,
}
Config to store needable state of the opentalk client

Fields

default_instance: Option<OpenTalkInstanceId>

Default OpenTalk instance

instances: BTreeMap<OpenTalkInstanceId, OpenTalkInstanceConfig>

OpenTalk instances

Implementations

Source

impl Config

pub fn get_default_instance( &self, ) -> Option<(OpenTalkInstanceId, OpenTalkInstanceConfig)>

Get the default instance if available.

pub fn get_instance( &self, instance_id: &OpenTalkInstanceId, ) -> Option<OpenTalkInstanceConfig>

Get an instance by its OpenTalkInstanceId.

pub fn get_default_account( &self, ) -> Option<(OpenTalkInstanceAccountId, OpenTalkAccountConfig)>

Get the default account if available.

This will return the default account of the default instance.

pub fn get_instance_with_fallback_to_default( &self, instance_id: Option<&OpenTalkInstanceId>, ) -> Option<(OpenTalkInstanceId, OpenTalkInstanceConfig)>

Get an instance config by an optional id, returning the default config if the id is None.

pub fn get_account_with_fallback_to_default( &self, instance_id: Option<&OpenTalkInstanceId>, account_id: Option<&OpenTalkAccountId>, ) -> Option<(OpenTalkInstanceAccountId, OpenTalkAccountConfig)>

Get an account config by optional ids, returning the default config at each level if the ids are None.

pub fn remove_account( &mut self, instance_id: Option<&OpenTalkInstanceId>, account_id: Option<&OpenTalkAccountId>, )

Remove an account from the configuration.