pub struct OpenTalkInstanceConfig {
pub default_account: OpenTalkAccountId,
pub accounts: BTreeMap<OpenTalkAccountId, OpenTalkAccountConfig>,
}Expand description
Configuration of an OpenTalk instance.
Fields
default_account: OpenTalkAccountIdThe id of the default account to use when using the OpenTalk instance.
accounts: BTreeMap<OpenTalkAccountId, OpenTalkAccountConfig>The accounts that are configured for an OpenTalk instance.
Implementations
Sourceimpl OpenTalkInstanceConfig
impl OpenTalkInstanceConfig
Sourcepub fn get_default_account(
&self,
) -> Option<(OpenTalkAccountId, OpenTalkAccountConfig)>
pub fn get_default_account( &self, ) -> Option<(OpenTalkAccountId, OpenTalkAccountConfig)>
Get the default instance if available.
Sourcepub fn get_account(
&self,
account_id: &OpenTalkAccountId,
) -> Option<OpenTalkAccountConfig>
pub fn get_account( &self, account_id: &OpenTalkAccountId, ) -> Option<OpenTalkAccountConfig>
Get an account by its OpenTalkAccountId.
Sourcepub fn get_account_with_fallback_to_default(
&self,
account_id: Option<&OpenTalkAccountId>,
) -> Option<(OpenTalkAccountId, OpenTalkAccountConfig)>
pub fn get_account_with_fallback_to_default( &self, account_id: Option<&OpenTalkAccountId>, ) -> Option<(OpenTalkAccountId, OpenTalkAccountConfig)>
Get an account config by an optional id, returning the default account if the id is None.
Sourcepub fn remove_account(&mut self, account_id: Option<&OpenTalkAccountId>)
pub fn remove_account(&mut self, account_id: Option<&OpenTalkAccountId>)
Remove an account from the configuration.